@@ -17,6 +17,6 @@ export function getGlobPattern(): string {
 export function getHighlightParsingError(): boolean {
   const { HIGHLIGHT_PARSING_ERRORS } = process.env
   return typeof HIGHLIGHT_PARSING_ERRORS !== 'undefined'
-    ? HIGHLIGHT_PARSING_ERRORS === 'true'
+    ? HIGHLIGHT_PARSING_ERRORS === 'true' || HIGHLIGHT_PARSING_ERRORS === '1'
     : true
 }
